DynamicInputTemplate class abstract

Annotations
  • @freezed

Constructors

DynamicInputTemplate({@InputNullableConverter.new() WoFormNode<Object?>? child, @notSerializable WoFormNode<Object?> childBuilder()?, @Default.new(DynamicInputUiSettings()) DynamicInputUiSettings uiSettings})
factory
DynamicInputTemplate.fromJson(Json json)
factory

Properties

child WoFormNode<Object?>?
no setterinherited
childBuilder WoFormNode<Object?> Function()?
no setterinherited
copyWith → $DynamicInputTemplateCopyWith<DynamicInputTemplate>
Create a copy of DynamicInputTemplate with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiSettings DynamicInputUiSettings
no setterinherited

Methods

getChild() WoFormNode<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
Serializes this DynamicInputTemplate to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited