MultistepAction class sealed

Annotations
  • @freezed

Constructors

MultistepAction.next()
Will find the current step in the steps, and push the step that is right after. If the current step is the last one, the form will be submitted, calling WoForm.onSubmitting.
const
factory
MultistepAction.popUntil(bool predicate(String stepId), {String? replacementStepId})
Will pop all the steps until predicate returns true. If provided, then will be executed next.
const
factory
MultistepAction.push({required String stepId})
Will push the step that has the id stepId. If there is generated steps after the one that is being submitted, and the next generated step has a different id, then all the next steps will be cleared.
const
factory
MultistepAction.submitForm()
Will submit the form, calling WoForm.onSubmitting.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited