MultistepAction.next constructor

const MultistepAction.next()

Will find the current step in the steps, and push the step that is right after. If the current step is the last one, the form will be submitted, calling WoForm.onSubmitting.

WARNING : WoForm.onSubmitting will be called even if other steps contain errors.

The steps can be RootNode.children, or WoFormValues.generatedSteps if MultistepSettings.onStepSubmitting != null.

Implementation

const factory MultistepAction.next() = MultistepActionNext;