SubmitButtonData class abstract

Annotations
  • @freezed

Constructors

SubmitButtonData({required String? text, required VoidCallback? onPressed, required String path, required SubmitButtonPosition position, IconData? icon})
const
factory

Properties

copyWith → $SubmitButtonDataCopyWith<SubmitButtonData>
Create a copy of SubmitButtonData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
no setterinherited
onPressed VoidCallback?
Callback invoked when the form (or a part of it) is submitted. This is triggered by the SubmitButton or any field configured to submit.
no setterinherited
path String
If not empty, submission validation will be scoped to the node at this path, and its children.
no setterinherited
position SubmitButtonPosition
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited