DynamicInputUiSettings class abstract
- Annotations
-
- @freezed
Constructors
- DynamicInputUiSettings({String? labelText, String? helperText, @notSerializable Widget? prefixIcon})
-
constfactory
- DynamicInputUiSettings.fromJson(Json json)
-
factory
Properties
-
copyWith
→ $DynamicInputUiSettingsCopyWith<
DynamicInputUiSettings> -
Create a copy of DynamicInputUiSettings
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
no setterinherited
- labelText → String?
-
no setterinherited
- prefixIcon → Widget?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
merge(
DynamicInputUiSettings? other) → DynamicInputUiSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DynamicInputUiSettings to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited