Will find the current step in the steps, and push the step
that is right after. If the current step is the last one, the form
will be submitted, calling WoForm.onSubmitting.
Will push the step that has the id stepId. If there is generated steps
after the one that is being submitted, and the next generated step has a
different id, then all the next steps will be cleared.