WoFormPresentation enum
This mode only affects the navigation controls.
You may use the default method to open a form:
/// Opens the form in a page, a bottom sheet or a dialog,
/// depending on [WoFormUiSettings.presentation].
context.openForm(
WoForm(...),
);
Or use your own:
showDialog(
context: context,
builder: (context) => Dialog(
child: WoForm(
uiSettings: WoFormUiSettings(
presentation: WoFormPresentation.dialog,
),
...
),
),
);
Values
- page → const WoFormPresentation
-
Suitable for forms with a dedicated screen in your app.
By default, the quit button is an < at the top-left of the form.
- dialog → const WoFormPresentation
-
Suitable for forms that you will display in a dialog.
By default, the quit button is an X at the top-right of the form.
- bottomSheet → const WoFormPresentation
-
Suitable for forms that you will display in a bottom sheet.
By default, there is no quit button.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isModal → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WoFormPresentation> - A constant List of the values in this enum, in order of their declaration.